@@ -24,9 +24,18 @@
  * @file ucommon/linked.h
  */
 
+/**
+ * An example of the linked object classes and their use.
+ * @example linked.cpp
+ */
+
 #ifndef _UCOMMON_LINKED_H_
 #define	_UCOMMON_LINKED_H_
 
+#ifndef _UCOMMON_CONFIG_H_
+#include <ucommon/platform.h>
+#endif
+
 #ifndef	_UCOMMON_OBJECT_H_
 #include <ucommon/object.h>
 #endif
